==> ejc-wpsofficeedit-api-3.0.1-20221115.075017-105-sources.jar: com/ejianc/business/wpsofficeedit/vo/BillEditInfoVO.java <==
package com.ejianc.business.wpsofficeedit.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 单据编辑信息VO
 *
 * @author CJ
 * @Description:
 * @date 2022/6/1 10:12
 */
public class BillEditInfoVO extends BaseVO {

    private static final long serialVersionUID = 3414362530203547556L;

    /**
     * 单据Id，与Id保持一致
     */
    private Long sourceId;

    /**
     * 单据编辑类型：合同模板、合同文件等
     */
    private String billEditType;

    /**
     * 文件对应二维码
     */
    private String qRCodeBase64;

    private String extraParam1;
    private String extraParam2;
    private String extraParam3;
    private Long extraParam4;
    private Long extraParam5;
    private Long extraParam6;

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getBillEditType() {
        return billEditType;
    }

    public void setBillEditType(String billEditType) {
        this.billEditType = billEditType;
    }

    public String getqRCodeBase64() {
        return qRCodeBase64;
    }

    public void setqRCodeBase64(String qRCodeBase64) {
        this.qRCodeBase64 = qRCodeBase64;
    }

    public String getExtraParam1() {
        return extraParam1;
    }

    public void setExtraParam1(String extraParam1) {
        this.extraParam1 = extraParam1;
    }

    public String getExtraParam2() {
        return extraParam2;
    }

    public void setExtraParam2(String extraParam2) {
        this.extraParam2 = extraParam2;
    }

    public String getExtraParam3() {
        return extraParam3;
    }

    public void setExtraParam3(String extraParam3) {
        this.extraParam3 = extraParam3;
    }

    public Long getExtraParam4() {
        return extraParam4;
    }

    public void setExtraParam4(Long extraParam4) {
        this.extraParam4 = extraParam4;
    }

    public Long getExtraParam5() {
        return extraParam5;
    }

    public void setExtraParam5(Long extraParam5) {
        this.extraParam5 = extraParam5;
    }

    public Long getExtraParam6() {
        return extraParam6;
    }

    public void setExtraParam6(Long extraParam6) {
        this.extraParam6 = extraParam6;
    }
}

==> ejc-wpsofficeedit-api-3.0.1-20250929.023713-172-sources.jar: com/ejianc/business/wpsofficeedit/vo/BillEditInfoVO.java <==
package com.ejianc.business.wpsofficeedit.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 单据编辑信息VO
 *
 * @author CJ
 * @Description:
 * @date 2022/6/1 10:12
 */
public class BillEditInfoVO extends BaseVO {

    private static final long serialVersionUID = 3414362530203547556L;

    /**
     * 单据Id，与Id保持一致
     */
    private Long sourceId;

    /**
     * 单据编辑类型：合同模板、合同文件等
     */
    private String billEditType;

    /**
     * 文件对应二维码
     */
    private String qRCodeBase64;

    /**
     * 单据类型编码
     */
    private String billType;

    /**
     * 所属分类Id
     */
    private Long categoryId;

    /**
     * 对应模板Id
     */
    private Long templateId;

    /**
     * 对应文件Id
     */
    private Long fileId;

    /**
     * 文件名称
     */
    private String fileName;

    /**
     * 文件路径
     */
    private String filePath;

    /**
     * 文件大小
     */
    private String fileSize;

    /**
     * 文件保存时是否替换原有文件
     */
    private Boolean fileReplace;

    private String extraParam1;
    private String extraParam2;
    private String extraParam3;
    private Long extraParam4;
    private Long extraParam5;
    private Long extraParam6;

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getBillEditType() {
        return billEditType;
    }

    public void setBillEditType(String billEditType) {
        this.billEditType = billEditType;
    }

    public String getqRCodeBase64() {
        return qRCodeBase64;
    }

    public void setqRCodeBase64(String qRCodeBase64) {
        this.qRCodeBase64 = qRCodeBase64;
    }

    public String getExtraParam1() {
        return extraParam1;
    }

    public void setExtraParam1(String extraParam1) {
        this.extraParam1 = extraParam1;
    }

    public String getExtraParam2() {
        return extraParam2;
    }

    public void setExtraParam2(String extraParam2) {
        this.extraParam2 = extraParam2;
    }

    public String getExtraParam3() {
        return extraParam3;
    }

    public void setExtraParam3(String extraParam3) {
        this.extraParam3 = extraParam3;
    }

    public Long getExtraParam4() {
        return extraParam4;
    }

    public void setExtraParam4(Long extraParam4) {
        this.extraParam4 = extraParam4;
    }

    public Long getExtraParam5() {
        return extraParam5;
    }

    public void setExtraParam5(Long extraParam5) {
        this.extraParam5 = extraParam5;
    }

    public Long getExtraParam6() {
        return extraParam6;
    }

    public void setExtraParam6(Long extraParam6) {
        this.extraParam6 = extraParam6;
    }

    public String getBillType() {
        return billType;
    }

    public void setBillType(String billType) {
        this.billType = billType;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public Long getTemplateId() {
        return templateId;
    }

    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }

    public Long getFileId() {
        return fileId;
    }

    public void setFileId(Long fileId) {
        this.fileId = fileId;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getFilePath() {
        return filePath;
    }

    public void setFilePath(String filePath) {
        this.filePath = filePath;
    }

    public String getFileSize() {
        return fileSize;
    }

    public void setFileSize(String fileSize) {
        this.fileSize = fileSize;
    }

    public Boolean getFileReplace() {
        return fileReplace;
    }

    public void setFileReplace(Boolean fileReplace) {
        this.fileReplace = fileReplace;
    }
}
